==> nextcloud-app-bookmarks-1%3A3.4.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/el.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Σελιδοδείκτες",
    "You bookmarked \"%s\"" : "Έχετε προσθέσει τον σελιδοδείκτη \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "Ο %1$s πρόσθεσε τον σελιδοδείκτη \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Κάποιος πρόσθεσε τον σελιδοδείκτη \"%s\"",
    "You deleted \"%s\"" : "Διεγράψατε το «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s διαγράφηκε \"%2$s\"",
    "Someone deleted \"%s\"" : "Κάποιος διαγράφηκε \"%s\"",
    "You created folder \"%s\"" : "Δημιουργήσατε τον φάκελο \"%s\"",
    "%1$s created folder \"%2$s\"" : "Ο %1$sδημιούργησε φάκελο \"%2$s\"",
    "Someone created folder \"%s\"" : "Κάποιος δημιούργησε τον φάκελο «%s»",
    "You moved folder \"%s\"" : "Μετακινήσατε τον φάκελο \"%s\"",
    "%1$s moved folder \"%2$s\"" : "Ο %1$s μετακίνησε τον φάκελο \"%2$s\"",
    "Someone moved folder \"%s\"" : "Κάποιος μετακίνησε τον φάκελο \"%s\"",
    "You deleted folder \"%s\"" : "Διαγράψατε το φάκελο \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "Ο %1$s διέγραψε το φάκελο \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Κάποιος διέγραψε το φάκελο \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Διαμοιράσατε το φάκελο \"%1$s\" με τον %2$s",
    "You shared folder \"%s\" with someone" : "Διαμοιράστε το φάκελο \"%s\" με κάποιον",
    "%1$s shared folder \"%2$s\" with you" : "Ο %1$sδιαμοίρασε το φάκελο \"%2$s\" μαζί σας",
    "Someone shared folder \"%s\" with you" : "Κάποιος διαμοίρασε το φάκελο \"%s\" μαζί σας",
    "You unshared folder \"%1$s\" with %2$s" : "Καταργήσατε την κοινή χρήση του φακέλου \"%1$s\" με τον %2$s",
    "You unshared folder \"%s\" with someone" : "Καταργήσατε την κοινή χρήση του φακέλου \"%s\" με κάποιον",
    "%1$s unshared folder \"%2$s\" with you" : "Ο %1$s κατάργησε την κοινή χρήση του φακέλου \"%2$s\" μαζί σας",
    "Someone unshared folder \"%s\" with you" : "Κάποιος κατάργησε την κοινή χρήση του φακέλου \"%s\" μαζί σας",
    "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
    "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
    "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
    "Bookmark" : "Σελιδοδείκτης",
    "Bookmark deleted" : "Ο σελιδοδείκτης διαγράφηκε",
    "Bookmark created" : "Ο σελιδοδείκτης δημιουργήθηκε",
    "Bookmark moved" : "Ο σελιδοδείκτης μετακινήθηκε",
    "Bookmark updated" : "Ο σελιδοδείκτης ενημερώθηκε",
    "Create bookmark" : "Δημιουργία σελιδοδείκτη",
    "Takes a link and adds it to your collection of bookmarks." : "Αυτή η ενέργεια, παίρνει έναν σύνδεσμο και τον προσθέτει στη συλλογή των σελιδοδεικτών σας.",
    "A Bookmark manager for Nextcloud" : "Διαχειριστής σελιδοδεικτών του Nextcloud",
    "Enter new title" : "Εισάγετε νέο τίτλο",
    "Select bookmark" : "Επιλογή σελιδοδείκτη",
    "Details" : "Λεπτομέρειες",
    "Rename" : "Μετονομασία",
    "Move" : "Μετακίνηση",
    "Delete" : "Διαγραφή",
    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
    "New" : "Νέα",
    "New bookmark" : "Νέος σελιδοδείκτης",
    "New folder" : "Νέος φάκελος",
    "Grid view" : "Προβολή πλέγματος",
    "List view" : "Προβολή λίστας",
    "Move selection" : "Μετακίνηση επιλογής",
    "Delete selection" : "Διαγραφή επιλογής",
    "Open all selected" : "Άνοιγμα των επιλεγμένων",
    "Select all" : "Επιλογή όλων",
    "Cancel selection" : "Ακύρωση επιλογής",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Επιλεγμένοι {folders} φάκελοι και {bookmarks} σελιδοδείκτες",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
    "_Selected %n folder_::_Selected %n folders_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
    "Enter a link" : "Εισάγετε σύνδεσμο",
    "Enter a title" : "Εισάγετε ένα τίτλο",
    "Select folder" : "Επιλογή φακέλου",
    "Enter folder title" : "Τίτλος φακέλου",
    "Shared by {user}" : "Διαμοιράστηκε από {user}",
    "Root folder" : "Αρχικός φάκελος",
    "Cancel" : "Ακύρωση",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Μετακίνηση %n φακέλου και μερικων σελιδοδεικτών","Μετακίνηση %nφακέλων και μερικων σελιδοδεικτών"],
    "_Moving %n folder_::_Moving %n folders_" : ["Μετακίνηση %n φακέλου","Μετακίνηση %n φακέλων"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Μετακίνηση %n σελιδοδείκτη","Μετακίνηση %n σελιδοδεικτών"],
    "All bookmarks" : "Όλοι οι σελιδοδείκτες",
    "Recent" : "Πρόσφατα",
    "Filter tags" : "Φίλτρο ετικετών",
    "Untagged" : "Χωρίς ετικέτα",
    "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
    "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ.",
    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Sorting" : "Ταξινόμηση",
    "Recently added" : "Προστέθηκαν πρόσφατα",
    "Alphabetically" : "Αλφαβητικά",
    "Most visited" : "Πιο δημοφιλή",
    "Last modified" : "Τελευταία τροποίηση",
    "Custom order" : "Προσαρμοσμένη εντολή",
    "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
    "Enter the path of a folder where bookmarked files should be stored" : "Προσθέστε την διαδρομή του φακέλου όπου θα αποθηκεύονται τα αρχεία σελιδοδεικτών",
    "Client apps" : "Εφαρμογές πελάτη",
    "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται σε αυτήν την εφαρμογή:",
    "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Σύρετε στους σελιδοδείκτες του περιηγητή και κάντε κλικ σε για γρήγορη αποθήκευση σελιδοδείκτη μιας ιστοσελίδας",
    "Add to {instanceName}" : "Προσθήκη στο {instanceName} ",
    "Clear data" : "Εκκαθάριση δεδομένων",
    "Delete all bookmarks" : "Διαγραφή όλων των σελιδοδεικτών",
    "Do you really want to delete all your bookmarks?" : "Θέλετε σίγουρα να διαγράψετε όλους σας τους σελιδοδείκτες;",
    "Title" : "Τίτλος",
    "Link" : "Σύνδεσμος",
    "Creation date" : "Ημερομηνία δημιουργίας",
    "Tags" : "Ετικέτες",
    "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
    "Attachments" : "Συνημμένα",
    "Notes" : "Σημειώσεις",
    "{time} ago" : "{time} πριν",
    "Owner" : "Κάτοχος",
    "Sharing" : "Διαμοιρασμός",
    "Select a user or group" : "Επιλογή χρήστη ή ομάδας",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Copy RSS feed" : "Αντιγραφή ροής πληροφοριών RSS",
    "Delete link" : "Διαγραφή συνδέσμου",
    "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Allow sharing" : "Να επιτρέπεται ο διαμοιρασμός",
    "Remove share" : "Κατάργηση διαμοιρασμού",
    "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
    "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
    "Select" : "Επιλογή",
    "Previews" : "Προεπισκοπήσεις",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Προκειμένου να προβάλλονται τα πραγματικά στιγμιότυπα οθόνης των ιστοσελίδων που προσθέτετε στους σελιδοδείκτες, η εφαρμογή Bookmarks μπορεί να χρησιμοποιήσει μια υπηρεσία τρίτου μέρους, για τη δημιουργία προεπισκόπησης.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Μπορείτε να εγγραφείτε δωρεάν στο screeenly.com είτε να ρυθμίσετε το δικό σας διακομιστή.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Κλειδί Screeenly API",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Απλά εγκαταστήστε το pageres cli στο διακομιστή σας και οι σελιδοδείκτες θα το βρουν.",
    "Privacy" : "Ιδιωτικότητα",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Οι σελιδοδείκτες θα προσπαθήσουν να έχουν πρόσβαση στις ιστοσελίδες που προσθέτετε για την αυτόματη πληροφόρησή σας.",
    "Enable accessing and collecting information from the web pages you add" : "Ενεργοποιήστε την πρόσβαση και συλλογή πληροφοριών των ιστοσελίδων που προσθέτετε",
    "Performance" : "Απόδοση",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
    "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
    "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
    "This URL is already bookmarked! Overwrite?" : "Υπάρχει ήδη σελιδοδείκτης με αυτή τη διεύθυνση URL! Αντικατάσταση;",
    "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
    "Enter bookmark URL" : "Καταχωρίστε τη διεύθυνση URL σελιδοδείκτη",
    "Folder" : "Φάκελος",
    "Root Folder" : "Αρχικός φάκελος",
    "Save" : "Αποθήκευση",
    "Failed to load bookmark" : "Αποτυχία φόρτωσης σελιδοδείκτη",
    "Failed to find existing bookmark" : "Απέτυχε η εύρεση υπάρχων σελιδοδείκτη",
    "Failed to create bookmark" : "Απέτυχε η δημιουργία σελιδοδείκτη",
    "Failed to save bookmark" : "Απέτυχε η αποθήκευση σελιδοδείκτη",
    "Failed to move bookmark" : "Απέτυχε η μετακίνηση σελιδοδείκτη",
    "Failed to delete bookmark" : "Απέτυχε η διαγραφή σελιδοδείκτη",
    "Failed to load tags" : "Απέτυχε η φόρτωση ετικετών",
    "Failed to load folders" : "Απέτυχε η φόρτωση φακέλων",
    "Failed to delete folder" : "Απέτυχε η διαγραφή φακέλου",
    "Failed to create folder" : "Απέτυχε η δημιουργία φακέλου",
    "Failed to fetch bookmarks." : "Αποτυχία λήψης σελιδοδεικτών.",
    "Failed to change setting" : "Αποτυχία αλλαγής επιλογών",
    "Failed to load setting {key}" : "Αποτυχία φόρτωσης ρυθμίσεων {key}",
    "Failed to update share {shareId}" : "Αποτυχία ενημέρωσης κοινόχρηστου {shareId}",
    "Failed to delete share {shareId}" : "Αποτυχία διαγραφής κοινόχρηστου {shareId}",
    "Bookmarks feed" : "Ροή σελιδοδεικτών"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A4.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/el.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Σελιδοδείκτες",
    "You bookmarked \"%s\"" : "Έχετε προσθέσει τον σελιδοδείκτη «%s»",
    "%1$s bookmarked \"%2$s\"" : "Ο %1$s πρόσθεσε τον σελιδοδείκτη «%2$s»",
    "Someone bookmarked \"%s\"" : "Κάποιος πρόσθεσε τον σελιδοδείκτη «%s»",
    "You deleted \"%s\"" : "Διεγράψατε το «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s διέγραψε «%2$s»",
    "Someone deleted \"%s\"" : "Κάποιος διέγραψε «%s»",
    "You created folder \"%s\"" : "Δημιουργήσατε τον φάκελο «%s»",
    "%1$s created folder \"%2$s\"" : "Ο %1$s δημιούργησε φάκελο «%2$s»",
    "Someone created folder \"%s\"" : "Κάποιος δημιούργησε τον φάκελο «%s»",
    "You moved folder \"%s\"" : "Μετακινήσατε τον φάκελο «%s»",
    "%1$s moved folder \"%2$s\"" : "Ο %1$s μετακίνησε τον φάκελο «%2$s»",
    "Someone moved folder \"%s\"" : "Κάποιος μετακίνησε τον φάκελο «%s»",
    "You deleted folder \"%s\"" : "Διαγράψατε το φάκελο «%s»",
    "%1$s deleted folder \"%2$s\"" : "Ο %1$s διέγραψε το φάκελο «%2$s»",
    "Someone deleted folder \"%s\"" : "Κάποιος διέγραψε το φάκελο «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Διαμοιράσατε το φάκελο «%1$s» με τον %2$s",
    "You shared folder \"%s\" with someone" : "Διαμοιράστε το φάκελο «%s» με κάποιον",
    "%1$s shared folder \"%2$s\" with you" : "Ο %1$s διαμοίρασε το φάκελο «%2$s» μαζί σας",
    "Someone shared folder \"%s\" with you" : "Κάποιος διαμοίρασε το φάκελο «%s» μαζί σας",
    "You unshared folder \"%1$s\" with %2$s" : "Καταργήσατε την κοινή χρήση του φακέλου «%1$s» με τον %2$s",
    "You unshared folder \"%s\" with someone" : "Καταργήσατε την κοινή χρήση του φακέλου «%s» με κάποιον",
    "%1$s unshared folder \"%2$s\" with you" : "Ο %1$s κατάργησε την κοινή χρήση του φακέλου «%2$s» μαζί σας",
    "Someone unshared folder \"%s\" with you" : "Κάποιος κατάργησε την κοινή χρήση του φακέλου «%s» μαζί σας",
    "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
    "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
    "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
    "Recent Bookmarks" : "Πρόσφατοι Σελιδοδείκτες",
    "Bookmark" : "Σελιδοδείκτης",
    "Bookmark deleted" : "Ο σελιδοδείκτης διαγράφηκε",
    "Bookmark created" : "Ο σελιδοδείκτης δημιουργήθηκε",
    "Bookmark moved" : "Ο σελιδοδείκτης μετακινήθηκε",
    "Bookmark updated" : "Ο σελιδοδείκτης ενημερώθηκε",
    "Create bookmark" : "Δημιουργία σελιδοδείκτη",
    "Takes a link and adds it to your collection of bookmarks." : "Αυτή η ενέργεια, παίρνει έναν σύνδεσμο και τον προσθέτει στη συλλογή των σελιδοδεικτών σας.",
    "A Bookmark manager for Nextcloud" : "Διαχειριστής σελιδοδεικτών του Nextcloud",
    "Enter new title" : "Εισάγετε νέο τίτλο",
    "Select bookmark" : "Επιλογή σελιδοδείκτη",
    "Details" : "Λεπτομέρειες",
    "Rename" : "Μετονομασία",
    "Move" : "Μετακίνηση",
    "Delete" : "Διαγραφή",
    "Do you really want to delete this bookmark?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον σελιδοδείκτη;",
    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
    "New" : "Νέα",
    "New bookmark" : "Νέος σελιδοδείκτης",
    "New folder" : "Νέος φάκελος",
    "Grid view" : "Προβολή πλέγματος",
    "List view" : "Προβολή λίστας",
    "RSS Feed of current view" : "RSS Feed της τρέχουσας προβολής",
    "Move selection" : "Μετακίνηση επιλογής",
    "Delete selection" : "Διαγραφή επιλογής",
    "Open all selected" : "Άνοιγμα των επιλεγμένων",
    "Select all" : "Επιλογή όλων",
    "Cancel selection" : "Ακύρωση επιλογής",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Επιλεγμένοι {folders} φάκελοι και {bookmarks} σελιδοδείκτες",
    "Do you really want to delete these items?" : "Θέλετε πραγματικά να διαγράψετε αυτά τα στοιχεία;",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
    "_Selected %n folder_::_Selected %n folders_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
    "Enter a link" : "Εισάγετε σύνδεσμο",
    "Enter a title" : "Εισάγετε ένα τίτλο",
    "No bookmarks found" : "Δεν βρέθηκαν σελιδοδείκτες",
    "Select folder" : "Επιλογή φακέλου",
    "Enter folder title" : "Τίτλος φακέλου",
    "Shared by {user}" : "Διαμοιράστηκε από {user}",
    "Do you really want to delete this folder?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον φάκελο;",
    "Root folder" : "Αρχικός φάκελος",
    "Submit" : "Υποβολή",
    "Cancel" : "Ακύρωση",
    "Deleting bookmarks" : "Γίνεται διαγραφή σελιδοδεικτών",
    "Deleting selection" : "Γίνεται διαγραφή της επιλογής",
    "Importing bookmarks" : "Γίνεται εισαγωγή σελιδοδεικτών",
    "Moving selection" : "Γίνεται μετακίνηση της επιλογής",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Μετακίνηση %n φακέλου και μερικων σελιδοδεικτών","Μετακίνηση %nφακέλων και μερικων σελιδοδεικτών"],
    "_Moving %n folder_::_Moving %n folders_" : ["Μετακίνηση %n φακέλου","Μετακίνηση %n φακέλων"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Μετακίνηση %n σελιδοδείκτη","Μετακίνηση %n σελιδοδεικτών"],
    "All bookmarks" : "Όλοι οι σελιδοδείκτες",
    "Recent" : "Πρόσφατα",
    "Archived" : "Αρχειοθετήθηκε",
    "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
    "Filter tags" : "Φίλτρο ετικετών",
    "Untagged" : "Χωρίς ετικέτα",
    "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
    "No archived bookmarks" : "Κανένας αρχειοθετημένος σελιδοδείκτης",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
    "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ",
    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
    "Import bookmarks" : "Εισαγωγή σελιδοδεικτών",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Sorting" : "Ταξινόμηση",
    "Recently added" : "Προστέθηκαν πρόσφατα",
    "Alphabetically" : "Αλφαβητικά",
    "Most visited" : "Πιο δημοφιλή",
    "Last modified" : "Τελευταία τροποίηση",
    "Custom order" : "Προσαρμοσμένη εντολή",
    "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
    "Enter the path of a folder where bookmarked files should be stored" : "Προσθέστε την διαδρομή του φακέλου όπου θα αποθηκεύονται τα αρχεία σελιδοδεικτών",
    "Client apps" : "Εφαρμογές πελάτη",
    "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται σε αυτήν την εφαρμογή:",
    "Install web app" : "Εγκατάσταση εφαρμογής ιστού",
    "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
    "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Σύρετε στους σελιδοδείκτες του περιηγητή και κάντε κλικ σε για γρήγορη αποθήκευση σελιδοδείκτη μιας ιστοσελίδας",
    "Add to {instanceName}" : "Προσθήκη στο {instanceName}",
    "Clear data" : "Εκκαθάριση δεδομένων",
    "Permanently remove all bookmarks from your account." : "Οριστική διαγραφή όλων των σελιδοδεικτών από το λογαριασμό σας.",
    "Delete all bookmarks" : "Διαγραφή όλων των σελιδοδεικτών",
    "Do you really want to delete all your bookmarks?" : "Θέλετε σίγουρα να διαγράψετε όλους σας τους σελιδοδείκτες;",
    "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
    "Title" : "Τίτλος",
    "Link" : "Σύνδεσμος",
    "Creation date" : "Ημερομηνία δημιουργίας",
    "Tags" : "Ετικέτες",
    "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
    "Attachments" : "Συνημμένα",
    "Archived version" : "Αρχειοθετημένη έκδοση",
    "Open archived file" : "Άνοιγμα αρχειοθετημένου αρχείου",
    "Notes" : "Σημειώσεις",
    "Notes for this bookmark …" : "Σημειώσεις για αυτό το σελιδοδείκτη …",
    "{time} ago" : "{time} πριν",
    "Owner" : "Κάτοχος",
    "Sharing" : "Διαμοιρασμός",
    "Select a user or group" : "Επιλογή χρήστη ή ομάδας",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Copy RSS feed" : "Αντιγραφή ροής πληροφοριών RSS",
    "Delete link" : "Διαγραφή συνδέσμου",
    "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Allow sharing" : "Να επιτρέπεται ο διαμοιρασμός",
    "Remove share" : "Κατάργηση διαμοιρασμού",
    "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
    "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
    "Select" : "Επιλογή",
    "Previews" : "Προεπισκοπήσεις",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Προκειμένου να προβάλλονται τα πραγματικά στιγμιότυπα οθόνης των ιστοσελίδων που προσθέτετε στους σελιδοδείκτες, η εφαρμογή Bookmarks μπορεί να χρησιμοποιήσει μια υπηρεσία τρίτου μέρους, για τη δημιουργία προεπισκόπησης.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Μπορείτε να εγγραφείτε δωρεάν στο screeenly.com είτε να ρυθμίσετε το δικό σας διακομιστή.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Κλειδί Screeenly API",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "Απλά εγκαταστήστε το pageres cli στο διακομιστή σας και οι σελιδοδείκτες θα το βρουν.",
    "Privacy" : "Ιδιωτικότητα",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Οι σελιδοδείκτες θα προσπαθήσουν να έχουν πρόσβαση στις ιστοσελίδες που προσθέτετε για την αυτόματη πληροφόρησή σας.",
    "Enable accessing and collecting information from the web pages you add" : "Ενεργοποιήστε την πρόσβαση και συλλογή πληροφοριών των ιστοσελίδων που προσθέτετε",
    "Performance" : "Απόδοση",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Σε μια εγκατάσταση με πολλούς χρήστες μπορεί να είναι χρήσιμο να περιοριστεί ο αριθμός των σελιδοδεικτών ανά λογαριασμό.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
    "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
    "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
    "This URL is already bookmarked! Overwrite?" : "Υπάρχει ήδη σελιδοδείκτης με αυτή τη διεύθυνση URL! Αντικατάσταση;",
    "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
    "Enter bookmark URL" : "Καταχωρίστε τη διεύθυνση URL σελιδοδείκτη",
    "Folder" : "Φάκελος",
    "Root Folder" : "Αρχικός φάκελος",
    "Save" : "Αποθήκευση",
    "Failed to count unavailable bookmarks" : "Αποτυχία μέτρησης μη διαθέσιμων σελιδοδεικτών",
    "Failed to count archived bookmarks" : "Αποτυχία μέτρησης αρχειοθετημένων σελιδοδεικτών",
    "Failed to load bookmark" : "Αποτυχία φόρτωσης σελιδοδείκτη",
    "Failed to find existing bookmark" : "Απέτυχε η εύρεση υπάρχων σελιδοδείκτη",
    "Failed to create bookmark" : "Απέτυχε η δημιουργία σελιδοδείκτη",
    "Failed to save bookmark" : "Απέτυχε η αποθήκευση σελιδοδείκτη",
    "Failed to move bookmark" : "Απέτυχε η μετακίνηση σελιδοδείκτη",
    "Failed to delete bookmark" : "Απέτυχε η διαγραφή σελιδοδείκτη",
    "Failed to rename tag" : "Αποτυχία μετονομασίας ετικέτας",
    "Failed to load tags" : "Απέτυχε η φόρτωση ετικετών",
    "Failed to load folders" : "Απέτυχε η φόρτωση φακέλων",
    "Failed to delete folder" : "Απέτυχε η διαγραφή φακέλου",
    "Failed to create folder" : "Απέτυχε η δημιουργία φακέλου",
    "Failed to fetch bookmarks." : "Αποτυχία λήψης σελιδοδεικτών.",
    "Failed to change setting" : "Αποτυχία αλλαγής επιλογών",
    "Failed to load setting {key}" : "Αποτυχία φόρτωσης ρυθμίσεων {key}",
    "Failed to update share {shareId}" : "Αποτυχία ενημέρωσης κοινόχρηστου {shareId}",
    "Failed to delete share {shareId}" : "Αποτυχία διαγραφής κοινόχρηστου {shareId}",
    "Bookmarks feed" : "Ροή σελιδοδεικτών"
},
"nplurals=2; plural=(n != 1);");
